###Package ####
library(readxl)
library(exactRankTests)
library(ggplot2)
library(ggpubr)
library(car)
library(PMCMR)
library(PMCMRplus)

###Websites ####
# https://www.bjoernwalther.com/kruskal-wallis-test-in-r-rechnen/
# https://www.bjoernwalther.com/levene-test-in-r-berechnen-und-interpretieren/  #Varianzhomogenität
# https://www.bjoernwalther.com/einfaktorielle-varianzanalyse-anova-in-r-rechnen/
# https://www.r-bloggers.com/2017/06/add-p-values-and-significance-levels-to-ggplots/
# https://www.uni-kiel.de/medinfo/lehre/seminare/methodik/Dtsch%20Arztebl%2012%20Auswahl%20statistischer%20Testverfahren.pdf ###test erklärungen

#### **** Seeds per kg **** #####################
#### Animals #####
tiere = read_excel(path = "../Data/1) AnzahlSamen.xlsx", sheet = 2, col_names = T)
tiere$Animal <- as.factor(tiere$Animal)

leveneTest(tiere$Seeds~ tiere$Animal) #Varianzhomogenität 
shapiro.test(tiere$Seeds)             #nicht normalverteilt
# -> Kruskal-Wallis, da nicht verbunden

windows.options(width = 6, height = 6)
dev.new ()
ggplot(tiere, aes(x = Animal, y = Seeds, fill = Animal))+
  scale_fill_manual (values = c("grey85", "grey60", "gray35")) +
  geom_boxplot(outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") + 
  stat_compare_means(method = "kruskal.test", label.x = 1.7, label.y = 47) + 
  theme(text = element_text(size = 12)) +
  ylab("Seeds per 100 g dry dung")
dev.off ()

#### Month ####
monat = read_excel(path = "../Data/1) AnzahlSamen.xlsx", sheet = 3, col_names = T)
monat$Month <- as.factor(monat$Month)

leveneTest(monat$Seeds~monat$Month) #Varianzhomogenität
shapiro.test(monat$Seeds)           # nicht normalverteilt
# -> verbunden, Wilcoxon test

wilcox.exact(monat$Seeds ~ monat$Month, paired = F )  #sig.

windows.options(width = 6, height = 6)
dev.new ()
ggplot(monat, aes(x = Month , y = Seeds, fill = Month))+
  scale_fill_manual (values = c("grey85", "grey50")) +
  geom_boxplot( outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") +
  stat_compare_means( method = "wilcox.test", label.x = 1.25, label.y = 52, paired = F)+
  stat_compare_means(label = "p.signif", method = "wilcox.test", label.y = 49, label.x = 1.4)+
  ylab("Seeds per 100 g dry dung")
dev.off()

#### Years ####
jahr = read_excel(path = "../Data/1) AnzahlSamen.xlsx", sheet = 4, col_names = T)
jahr$Year <- as.factor(jahr$Year)
jahr$Samptime

leveneTest(jahr$Seeds~jahr$Year) ### Varianzhomogenität
shapiro.test(jahr$Seeds)         ### nicht normalverteilt
# nicht verbunden, Mann-Whitney U Test

wilcox.exact(jahr$Seeds ~ jahr$Year, paired = T) #nichtsig.

dev.new ()
windows.options(width = 6, height = 6)
ggplot(jahr, aes(x = Year , y = Seeds, fill = Year))+
  scale_fill_manual (values = c("grey85", "gray50")) +
  geom_boxplot( outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  stat_compare_means( method = "wilcox.test", label.x = 1.3, label.y = 50, paired = T)+
  ylab("Seeds per 100 g dry dung")
dev.off()


#### sampling times ###
kruskal.test(Seeds ~ Samptime, data = jahr)

############# ***** Species Richness ****** ###############
arten = read_excel(path = "../Data/2) Artenzahl.xlsx", sheet = 1, col_names = T)
arten$Tiere <- as.factor(arten$Animal)
arten$Month <- as.factor(arten$Month)
arten$Year <- as.factor(arten$Year)

#### testing ####
leveneTest(arten$Species ~ arten$Animal) #Varianhomogenität
leveneTest(arten$Species ~ arten$Month)  #Varianhomogenität
leveneTest(arten$Species ~ arten$Year)   #Varianhomogenität
shapiro.test(arten$Species)              #nicht normalverteilt
# -> Kruskal-Wallis (Animal), Wilcox da verbunden (Month), Mann-Whitney-U da nicht verbunden (Year)

#### plotting ####
#### Animal ####
dev.new ()
windows.options(width = 6, height = 6)
ggplot(arten, aes(x = Animal, y = Species, fill = Animal))+
  scale_fill_manual (values = c("grey85", "grey60", "gray35")) +
  geom_boxplot(outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") + 
  theme(text = element_text(size = 12, family = "TT Times New Roman")) +
  stat_compare_means(method = "kruskal.test", label.x = 1.75, label.y = 42)+
  stat_compare_means(label = "p.signif", method = "wilcox.test", ref.group = ".all.", label.y = 39) +
  ylab("Species per dung sample")
dev.off()

#### Month ####
dev.new ()
windows.options(width = 6, height = 6)
ggplot(arten, aes(x = Month , y = Species, fill = Month))+
  scale_fill_manual (values = c("grey85", "grey50")) +
  geom_boxplot( outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") +
  stat_compare_means( method = "wilcox.test", label.x = 1.2, label.y = 42, paired = F)+
  stat_compare_means(label = "p.signif", method = "wilcox.test", label.y = 40, label.x = 1.4)+
  ylab("Species per dung sample")
dev.off()

#### Year ####
dev.new()
windows.options(width = 6, height = 6)
ggplot(arten, aes(x = Year , y = Species, fill = Year))+
  scale_fill_manual (values = c("grey85", "gray50")) +
  geom_boxplot( outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  stat_compare_means( method = "wilcox.test", label.x = 1.3, label.y = 41, paired = T)+
  ylab("Species per dung sample")
dev.off()
