library(readxl)
library(ggplot2)
library(ggpubr)

#############----------------------------------------- for all Days seperately -------------------- ####################

####  -------- Data loading ------- #####
### Traits + cleaning #####
traits <-read_excel(path = "../Data/3) Merkmale01.xlsx", na = "NA", sheet = 2, col_names = T)
traits <- as.data.frame(traits)
names <- traits$Art 
rownames(traits) <- names
traits$Art <- NULL

##Veg ####
Veg <- read_excel(path = "../Data/3) Merkmale01.xlsx", sheet = 1, col_names = T)
Veg <- as.data.frame(Veg)
names <- Veg$Plot
rownames(Veg) <- names
Veg$Plot <- NULL
Veg$Group<- NULL
Veg$Trial <- NULL
Veg <- as.data.frame(t(Veg))

########### Soziology --- 2 row #####
Soziology <- matrix(ncol = ncol(Veg), nrow = nrow(Veg))
rownames(Soziology) <- rownames(Veg)
colnames(Soziology) <- colnames(Veg)

for(i in 1:nrow(Soziology)){
  for(j in 1:ncol(Soziology)){
    Gesamtdeckung_j <- Veg[,j]
    Gesamtdeckung <- Gesamtdeckung_j[which(traits[,2] != "NA")]
    if(Veg[i,j] == 0.){ 
      Soziology[i,j] = NA
    }
    else{
      Soziology[i,j] <- traits[i,2]*Veg[i,j]/sum(Gesamtdeckung)# nummer ersetzten
    }
  }
}

Soziology_overview <- matrix(ncol = ncol(Soziology),nrow = 1)
rownames(Soziology_overview) = "Mittelwert"
colnames(Soziology_overview) = colnames(Soziology)

for(j in 1:ncol(Soziology)){
  Soziology_overview[1,j] = sum(Soziology[,j],na.rm =T)
}

Soziology <- as.data.frame(Soziology)
Soziology_overview <- as.data.frame(Soziology_overview)
names <- c("Soz")
rownames(Soziology_overview) <- names

########### Rote Liste Bayern --- 3 row #####
RoteListeB <- matrix(ncol = ncol(Veg), nrow = nrow(Veg))
rownames(RoteListeB) <- rownames(Veg)
colnames(RoteListeB) <- colnames(Veg)

for(i in 1:nrow(RoteListeB)){
  for(j in 1:ncol(RoteListeB)){
    Gesamtdeckung_j <- Veg[,j]
    Gesamtdeckung <- Gesamtdeckung_j[which(traits[,3] != "NA")]
    if(Veg[i,j] == 0.){ 
      RoteListeB[i,j] = NA
    }
    else{
      RoteListeB[i,j] <- traits[i,3]*Veg[i,j]/sum(Gesamtdeckung)# nummer ersetzten
    }
  }
}

RoteListeB_overview <- matrix(ncol = ncol(RoteListeB),nrow = 1)
rownames(RoteListeB_overview) = "Mittelwert"
colnames(RoteListeB_overview) = colnames(RoteListeB)

for(j in 1:ncol(RoteListeB)){
  RoteListeB_overview[1,j] = sum(RoteListeB[,j],na.rm =T)
}

RoteListeB <- as.data.frame(RoteListeB)
RoteListeB_overview <- as.data.frame(RoteListeB_overview)
names <- c("RLB")
rownames(RoteListeB_overview) <- names


#### ----------------- Gesamte Liste ----------------------------------- #############
AlleMerkmale <- rbind(Soziology_overview, RoteListeB_overview)
AlleMerkmale <- as.data.frame(AlleMerkmale)

write.csv(AlleMerkmale, file = "./Output/AlleMerkmale.csv")
#saved under 4) RL.xlsx#

######## Plotting ########

#Data
traits <-read_excel(path = "../Data/4) RL.xlsx", na = "NA", sheet = 1, col_names = T)
names <- traits$Plot
rownames(traits) <- names
traits$Plot <- NULL
traits$Trial <- as.factor(traits$Trial)
traits$Group <- as.factor((traits$Group))

### plotting #####
dataplotting <- traits

#### Sociology #####
dev.new () ##not sig. 
windows.options(width = 6, height = 6)
ggplot(data = dataplotting, aes( x = Group, y = Soz, group = Group, fill = Group) )+
  scale_fill_manual (labels = c("1: Vegetation", "2: Cattle", "3: Goat", "4: Sheep"), values = c("grey85", "grey60", "gray35", "grey5")) +
  geom_boxplot(outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") + 
  stat_compare_means(method = "kruskal.test", label.x = 2.2, label.y = 1.12) + 
  stat_compare_means(label = "p.signif", method = "wilcox.test", ref.group = ".all.", label.y = 1.05)+
  theme(text = element_text(size = 12, family = "TT Times New Roman")) +
  ylab("tpyical calcareous grassland species")
dev.off ()

####Rote Liste Bayern ####
dev.new ()  ###sign. 
windows.options(width = 6, height = 6)
ggplot(data = dataplotting, aes( x = Group, y = RLB, group = Group, fill = Group) )+
  scale_fill_manual (labels = c("1: Vegetation", "2: Cattle", "3: Goat", "4: Sheep"), values = c("grey85", "grey60", "gray35", "grey1")) +
  geom_boxplot(outlier.colour = "black", outlier.shape = 2, outlier.size = 2) + 
  theme_classic() +
  theme (legend.position = "right") + 
  stat_compare_means(method = "kruskal.test", label.x = 2.2, label.y =1) + 
  stat_compare_means(label = "p.signif", method = "wilcox.test", ref.group = ".all.", label.y = 0.93)+
  theme(text = element_text(size = 12, family = "TT Times New Roman")) +
  ylab("Red List Species for Bavaria")
dev.off ()