#Websites #####
# https://rpubs.com/brownjk5/NMDS
#https://www.youtube.com/watch?v=Kl49qI3XJKY
#https://www.youtube.com/watch?v=QljEeBei-JA
#https://rdrr.io/cran/goeveg/man/ordiselect.html

# Packages ######
library("vegan")
library("readxl")
library("RColorBrewer")
library("goeveg")

######## Data Overview #####
#Data (Sheet 1) in allpatches_data for pairs of clear-cuts to respective references
#First col: Patch_name_year 
#Second col: RM = Rodung R (clearance) or Magerrasen M (calc. grassland)
#Third col: AgeR = Age of afforestation before clearance in years
#Forth col: Field = Name of research area (= 10 different)
#Fifth col: AgeBr= Age since beginning of vegetation recording starting 1 (= 1993) to 25 (= 2019)
#Sixth col: Before = what kind of shrubs or trees before clearance (Ki= pine, Fi= spruce, Schl= blackthorn, Mw = mixed forest, Ro = robinia)
#Seventh col: Area name without year
#Data (Sheet 2) weighted mean indicator values (calculated in Skript EIV_MW) & above mentioned parameters at the end

### read data and editing ####
# Vegetation (sheet 1)
allpatches <- read_excel(path = "../Data/1) allpatches_MW.xlsx", col_names = T, sheet =1) #sheet - which excel sheet to choose
allpatches = as.data.frame(allpatches) 

# edits in table
rownames (allpatches) <- allpatches [,1] # give rownames species names!  
allpatches <- allpatches[,-1] # and delete species in first column!
allpatches[ allpatches < 0.05 & allpatches != 0] <- 0.05 # values bigger than 0 but smaller than 0.5 get the value 0.5!

#### ALL #########################################################
### Vegetation
Vegall <- allpatches

#Restoration Indicators
InVa <- read_excel(path = "../Data/1) allpatches_MW.xlsx", col_names = T, sheet =3)
InVa = as.data.frame(InVa[8:13])

cor = cor(InVa)
library(corrplot)
corrplot(cor, method = "number") # N mit F korr. & F mit Vork. 

#### Seperate Vegetation from additional parameters! 
Veg = Vegall[,7:ncol(Vegall)] #nur Veg
RM = as.integer(as.factor(Vegall$RM))
RM = as.data.frame(RM)
names(RM)[1] <- "Clearcut"
AgeR = as.integer(Vegall$AgeR)
AgeR = as.data.frame(AgeR)
names(AgeR) [1] <- "Aff.age"
Field = Vegall$Field
Field = as.data.frame(Field)
AgeBR = Vegall$AgeBR
AgeBR = as.data.frame(AgeBR)
names(AgeBR) [1] <- "Time"
Before = (as.character(Vegall$Before))
Before[Before == "Schl"] <- "Blackthorn"
Before[Before == "Ro"] <- "Black locust"
Before[Before == "Ki"] <- "Pine"
Before[Before == "Ma"] <- "Reference"
Before[Before == "Fi"] <- "Spruce"
Before = as.data.frame(Before)
Area = Vegall$Area
Area = as.data.frame(Area)

#NMDS calculation
NMDS = metaMDS(Veg, k=3, trymax = 100)
NMDS
stressplot(NMDS)
anosim(Veg, RM$Clearcut) # unterschiede in Gruppen
distance_Veg = vegdist(Veg) 
anova(betadisper(distance_Veg, RM$Clearcut)) # sig - not good #eigtl vorraussetzung fuer adonis
fit = adonis(Veg ~ Clearcut, data = RM) # sig - passt

###fitting of parameters
RMfit <- envfit(NMDS, RM, display = "sites") #Clearance or Reference
AgeBRfit<- envfit (NMDS, AgeBR, display = "sites") #Age since clearance
AgeRfit <- envfit (NMDS, AgeR, display = "sites") #Age forest before clearance
EIVfit <- envfit(NMDS, InVa, display = "sites")
Beforefit <- envfit(NMDS, Before, display = "sites")
# RMfit$vectors # table for p-values


# plotting of NMDS for all 
windows.options(width = 14, height = 9)  #  size of external window
dev.new () #external window - for same looks of all NMDS
co = c("chartreuse3","lightskyblue2","royalblue3","tomato3","orange3", "grey35","mediumorchid3" )
shape = c(19,2) # code for symbols used to display sites
plot(NMDS$points, col = co[Field$Field], pch = shape[RM$Clearcut], cex = 1.2, main = "", xlab = "Axis 1", ylab = "Axis 2")
#s.class(NMDS$points, Before$Before, grid = F, addaxes = F)
# orditorp(NMDS, display = "sites", col = co[RM$RM], air = 1, text.default(x = NMDS$points[,1],   #name Flächen
#                                                                          y  = NMDS$points[,2],
#                                                                         labels = rownames(NMDS$points),
#                                                                         adj = c(0.5,1.5), cex = 0.6))
ordiarrows(NMDS, groups = Area$Area , col = "gray70")
txt <- c("Reference", "Restoration")
legend('topright',txt, pch = c(19,2), col = "black", cex = 1.1, bty = "n") #bty heisst keine Linien
plot(RMfit, p.max = 0.001, col = "gray30", cex = 1.1, font =2) ####Speichern!!!
plot(AgeRfit, p.max = 0.01, col = "gray30", cex = 1.1, font = 2) ####Speichern!!! ### p aendern ?
plot(EIVfit, p.max = 0.05, col = "black", cex = 1.1)
plot(Beforefit, p.max = 0.05, col = "black", cex = 1.1, font = 2)
sfit <- envfit(NMDS, Veg, display= "sites") #speciesfit
plot(sfit, p.max = 0.001, col = "gray40", cex = 1.1, font = 3)

###   save PDF ### 