# calculate Species Richness (SR) for each plot (step 1) and test differences (step 2)
###libraries####
library(readxl)
library( dplyr)
library(ggpubr)
library(exactRankTests)
library(muStat)
library(vegan)

#manuals: ######
#https://www.flutterbys.com.au/stats/tut/tut13.2.html
## http://www.sthda.com/english/wiki/comparing-means-in-r

#data per plot per transect per year #####
allpatches_traits <- read_excel(path = "../Data/2) allpatches_plots.xlsx", col_names = T, sheet =1) #sheet - which excel sheet to choose
allpatches = as.data.frame(allpatches_traits)

# edits in table before calculations #####
rownames (allpatches) <- allpatches [,1] # give rownames species names!  
allpatches <- allpatches[,-1] # and delete species in first column!
for(i in 7:ncol(allpatches)){
  allpatches[,i] <- as.numeric(as.character(allpatches[,i])) #also possible that species are rated as integer ...
}

#seperation of Vegetation from additional parameters
Veg <- allpatches[,7:ncol(allpatches)] #species
names <- rownames(allpatches)

####Species Richness calculations #######
SR = apply(Veg>0,1, sum)
SR = as.data.frame(SR, row.names = names)
SR = as.numeric(SR$SR)
SR = as.data.frame(SR)
rownames(SR) <- names

###new matrix for mean calculations####
SR_all <- cbind (allpatches[1:6],SR, names) #matrix for calculations
write.csv(SR_all, "./Output/ 4) SR_per_plot_ALL.csv", row.names = T)

SR_all$grouping = paste0 (SR_all$Area, SR_all$AgeBR) 
SR_all$grouping1 = paste0(SR_all$RM, SR_all$AgeBR)

#####################################################################################
#######ALL###################################
#######mean - ALL ##############
#calculations means per Area
mean = aggregate(SR_all$SR, by = list(SR_all$grouping), FUN = mean)
SR_total = as.data.frame(mean) 
write.csv(SR_total, "./Output/ 4) SR_per_year_All.csv", row.names = T) #per transect means

#calculate means per Year
mean = aggregate(SR_all$SR, by = list(SR_all$grouping1), FUN = mean)
SR_total = as.data.frame(mean) 
write.csv(SR_total, "./Output/ 4) SR_per_management_All.csv", row.names = T) #per management

#######Mann-Whitney-U - ALL ############

#normalverteilung
SR_A = SR_all
shapiro.test(SR_A$SR) # nicht normalverteilt 
wilcox.exact(SR ~ RM, data = SR_A) #paired = F is default für Mann-Whitney-U test / Wilcoxon-test braucht paired = T

#1993
SR_A_1 = SR_A %>% filter (AgeBR == 1)
shapiro.test(SR_A_1$SR) #test homogenität/ Normalverteilung
var.test(SR ~ RM, data = SR_A_1) #sig. daher keine Varianzgleichheit ---> Mann-Whitney-U
wilcox.exact(SR_A_1$SR ~ SR_A_1$RM)
#1994
SR_A_2 = SR_A %>% filter (AgeBR == 2)
wilcox.exact(SR_A_2$SR ~ SR_A_2$RM)
#2001
SR_A_8 = SR_A %>% filter (AgeBR == 8)
wilcox.exact(SR_A_8$SR ~ SR_A_8$RM)
#2008
SR_A_15 = SR_A %>% filter (AgeBR == 15)
wilcox.exact(SR_A_15$SR ~ SR_A_15$RM)
#2013
SR_A_20 = SR_A %>% filter (AgeBR == 20)
wilcox.exact(SR_A_20$SR ~ SR_A_20$RM)
#2018
SR_A_25 = SR_A %>% filter (AgeBR == 25)
wilcox.exact(SR_A_25$SR ~ SR_A_25$RM)

