####Packages & Tutorials ######
#https://rpubs.com/CPEL/cwm
#https://www.youtube.com/watch?v=DPfFNVpt4po #Friedman.test
library(readxl)
library(tidyr)
library(dplyr)
library(coin)
library(exactRankTests)
library(muStat)
library(FD)
library(PMCMRplus)

###########data loading #####
#Vegetation data
allpatches_traits <- read_excel(path = "../Data/2) allpatches_plots.xlsx", col_names = T, sheet =1) #sheet - which excel sheet to choose
allpatches = as.data.frame(allpatches_traits)
rownames (allpatches) <- allpatches [,1] # give rownames species names!  
allpatches <- allpatches[,-1] # and delete species in first column!
allpatches[ allpatches < 0.05 & allpatches != 0] <- 0.05 #all values lower than 0.05 get the value 0.05
for(i in 7:ncol(allpatches)){
  allpatches[,i] <- as.numeric((allpatches[,i])) #also possible that species are rated as integer ...
}
Veg <- allpatches[,7:ncol(allpatches)] #species
Veg <- as.matrix (Veg) #for CWM calculations

#EIV data
values <- read_excel(path = "../Data/2) allpatches_plots.xlsx", col_names = T, sheet =2)
values <- as.data.frame(values)
for(i in 3:9) {
  values[,i] <- as.numeric(as.character(values[,i])) #NAs werden behalten # as.numeric fuer Berechnung
} 
names <- values$Species
values2 <- values[,3:ncol(values)] 
rownames(values2) <- names
values2 <- as.data.frame(values2)

###########calculations of CWM ######
which(c(colnames(Veg)) %in% c(rownames(values2)) ==F) #überprüfen ob alle gleich! 
CWM <- functcomp(values2, Veg, CWM.type = "all")

###########new matrix for mean calculations####
cwm <- cbind (allpatches[1:6],CWM) #matrix for calculations
write.csv(cwm, "./Output/5) CWM_for_7.csv")
cwmAll = cwm

##### cwm - mean calculations ####################################################
####ALL######
#plot per year - means ####
grouping <- paste0 (cwmAll$Area, cwmAll$AgeBR) 
grouping <- as.factor(grouping)
cwmAll2 <- cbind(grouping, cwmAll)  #grouping nach Jahr und Fläche eingefügt
write.csv(cwmAll2, "./Output/5) CWM_per_plot.csv")

#transect per year - means ###
sites <- unique(cwmAll2$grouping)  #nur Werte, die einmalig vorkommen werden gefiltert
mean_matrix_All = as.data.frame(matrix(ncol = ncol(cwmAll2)-6,nrow = length(sites)))  
colnames(mean_matrix_All) = c("Site", colnames(cwmAll2[,8:ncol(cwmAll2)]))

for(i in 1:length(sites)){
  mean_matrix_All[i,1] = as.character(sites[i])
  mean_matrix_All[i,2:9] = apply(FUN = mean, X= cwmAll2[grouping == sites[i],8:ncol(cwmAll2)], MARGIN = 2)
}
write.csv(mean_matrix_All, "./Output/5) Mean_per_year_All.csv", row.names = T)

#treatment (RM) means per year
cwmAll = cwm 
grouping <- paste0 (cwmAll$RM, cwmAll$AgeBR)
grouping <- as.factor(grouping)
cwmAll2 <- cbind(grouping, cwmAll)  #grouping nach Jahr und Fläche eingefügt

sites <- unique(cwmAll2$grouping)  #nur Werte, die einmalig vorkommen werden gefiltert
mean_matrix_All = as.data.frame(matrix(ncol = ncol(cwmAll2)-6,nrow = length(sites)))  
colnames(mean_matrix_All) = c("Site", colnames(cwmAll2[,8:ncol(cwmAll2)]))

for(i in 1:length(sites)){
  mean_matrix_All[i,1] = as.character(sites[i])
  mean_matrix_All[i,2:9] = apply(FUN = mean, X= cwmAll2[grouping == sites[i],8:ncol(cwmAll2)], MARGIN = 2)
}
write.csv(mean_matrix_All, "./Output/5) Mean_per_Treatment_All.csv", row.names = T) ###Werte in Tabelle


###########testing###################################################################
###testing#ALL#####
cwmAll2 # CWMs mit grouping variable!
#shapiro - normal distibution - p < 0.05 not normally dist.! #####
shapiro.test(cwmAll2$EIVF) #->alle n.n., daher Mann-Whitney-U-test


###Mann-Whitney-U-test - ALL ##########
scale <- scale(cwmAll2[,8:ncol(cwmAll2)])
cwmAll22 <- cbind(cwmAll2[, 1:7], scale)
cwmAll2 <- cwmAll22
#year1993
cwmAll2_1 = cwmAll2 %>% filter (AgeBR == 1)
wilcox.exact(cwmAll2_1$EIVF ~ cwmAll2_1$RM)
wilcox.exact(cwmAll2_1$EIVL ~ cwmAll2_1$RM)
wilcox.exact(cwmAll2_1$EIVR ~ cwmAll2_1$RM)
wilcox.exact(cwmAll2_1$EIVN ~ cwmAll2_1$RM)
wilcox.exact(cwmAll2_1$Vork_1 ~ cwmAll2_1$RM)
wilcox.exact(cwmAll2_1$RL_1 ~ cwmAll2_1$RM)

#year1994
cwmAll2_2 = cwmAll2 %>% filter (AgeBR == 2)
wilcox.exact(cwmAll2_2$EIVF ~ cwmAll2_2$RM)
wilcox.exact(cwmAll2_2$EIVL ~ cwmAll2_2$RM)
wilcox.exact(cwmAll2_2$EIVR ~ cwmAll2_2$RM)
wilcox.exact(cwmAll2_2$EIVN ~ cwmAll2_2$RM)
wilcox.exact(cwmAll2_2$Vork_1~ cwmAll2_2$RM)
wilcox.exact(cwmAll2_2$RL_1 ~ cwmAll2_2$RM)

#year2001
cwmAll2_8 = cwmAll2 %>% filter (AgeBR == 8 )
wilcox.exact(cwmAll2_8$EIVF ~ cwmAll2_8$RM)
wilcox.exact(cwmAll2_8$EIVL ~ cwmAll2_8$RM)
wilcox.exact(cwmAll2_8$EIVR ~ cwmAll2_8$RM)
wilcox.exact(cwmAll2_8$EIVN ~ cwmAll2_8$RM)
wilcox.exact(cwmAll2_8$Vork_1 ~ cwmAll2_8$RM)
wilcox.exact(cwmAll2_8$RL_1 ~ cwmAll2_8$RM)

#year2008
cwmAll2_15 = cwmAll2 %>% filter (AgeBR == 15 )
wilcox.exact(cwmAll2_15$EIVF ~ cwmAll2_15$RM)
wilcox.exact(cwmAll2_15$EIVL ~ cwmAll2_15$RM)
wilcox.exact(cwmAll2_15$EIVR ~ cwmAll2_15$RM)
wilcox.exact(cwmAll2_15$EIVN ~ cwmAll2_15$RM)
wilcox.exact(cwmAll2_15$Vork_1~ cwmAll2_15$RM)
wilcox.exact(cwmAll2_15$RL_1 ~ cwmAll2_15$RM)

#year2013
cwmAll2_20 = cwmAll2 %>% filter (AgeBR == 20 )
wilcox.exact(cwmAll2_20$EIVF ~ cwmAll2_20$RM)
wilcox.exact(cwmAll2_20$EIVL ~ cwmAll2_20$RM)
wilcox.exact(cwmAll2_20$EIVR ~ cwmAll2_20$RM)
wilcox.exact(cwmAll2_20$EIVN ~ cwmAll2_20$RM)
wilcox.exact(cwmAll2_20$Vork_1 ~ cwmAll2_20$RM)
wilcox.exact(cwmAll2_20$RL_1 ~ cwmAll2_20$RM)

#year2018
cwmAll2_25 = cwmAll2 %>% filter (AgeBR == 25 )
wilcox.exact(cwmAll2_25$EIVF ~ cwmAll2_25$RM)
wilcox.exact(cwmAll2_25$EIVL ~ cwmAll2_25$RM)
wilcox.exact(cwmAll2_25$EIVR ~ cwmAll2_25$RM)
wilcox.exact(cwmAll2_25$EIVN ~ cwmAll2_25$RM)
wilcox.exact(cwmAll2_25$Vork_1 ~ cwmAll2_25$RM)
wilcox.exact(cwmAll2_25$RL_1 ~ cwmAll2_25$RM)